@@ -1,4 +1,4 @@
-// Copyright  1995-1999 The Santa Fe Institute.
+// Copyright  1995-2000 Swarm Development Group.
 // No warranty implied, see LICENSE for terms.
 
 
@@ -45,7 +45,8 @@ int compFunc( id a, id b ) {
 
   // init defaults
   obj->initPopSize = 100;
-  obj->popSize=obj->initPopSize; // Without probe
+  obj->popSize = 0;
+
   obj->chromLen = 0;
   obj->mating = 0.1;		// Good for the demo problem
   obj->mut = 0.05;
@@ -101,22 +102,22 @@ int compFunc( id a, id b ) {
 
 // __________________________
 // Build simulation objects
--buildObjects {
-
+- buildObjects
+{
   [super buildObjects];
   newPopList = [List create: [self getZone]];
-
+  
   // Create Uname generator
   Generator = [UName create:[self getZone] setBaseName: "gen0X"];
-
+  
   // Create initial random population
   [self addPopulation: initPopSize];
-   
+  
   // Create intial map, to keep evaluated genes
   popList = [Map createBegin: [self getZone]];
   [popList setCompareFunction: compFunc];
   popList = [popList createEnd];
-
+  
   return self;
 }
 
@@ -233,7 +234,6 @@ int compFunc( id a, id b ) {
     i = 0; 
     index = [ popList begin: [self getZone]];
     [index setLoc: End];
-
     while( ( i < killQuant) && (stiff = [index prev] ) ){
       if ( verbose ) {
 	printf("[%s %f]\n", [stiff getID], [stiff getFitness] );
@@ -253,10 +253,10 @@ int compFunc( id a, id b ) {
 	BinChromosome *gen, *parentA, *parentB;
 	parentA = [popList atOffset: 
 			     [uniformUnsRand getUnsignedWithMin: 0L 
-					     withMax:[popList count] - 1] ];
+					     withMax:[popList getCount] - 1] ];
 	parentB = [popList atOffset: 
 			     [uniformUnsRand getUnsignedWithMin: 0L 
-					     withMax:[popList count] - 1] ];
+					     withMax:[popList getCount] - 1] ];
 	
 	gen = [BinChromosome createBegin: [self getZone]];
 	[gen setID: [Generator getNewName]];
@@ -277,7 +277,7 @@ int compFunc( id a, id b ) {
       BinChromosome *gen, *parent;
       parent = [popList atOffset:
 			  [uniformUnsRand getUnsignedWithMin: 0L 
-					  withMax:[popList count] - 1] ];
+					  withMax:[popList getCount] - 1] ];
       gen = [BinChromosome createBegin: [self getZone]];
       [gen setID: [Generator getNewName]];
       [gen Clone: parent withMutation: mut];
@@ -297,7 +297,7 @@ int compFunc( id a, id b ) {
 	parent = 
 	    [popList atOffset:
 		       [uniformUnsRand getUnsignedWithMin: 0L 
-				       withMax:[popList count] - 1]];
+				       withMax:[popList getCount] - 1]];
 	
 	geneIndex = [uniformUnsRand getUnsignedWithMin: 0L 
 				    withMax:[parent getLength] - 1];
@@ -320,7 +320,7 @@ int compFunc( id a, id b ) {
 	unsigned geneIndex1, geneIndex2;
 	parent = 
 	    [popList atOffset: [uniformUnsRand getUnsignedWithMin: 0L 
-				       withMax:[popList count] - 1]];
+				       withMax:[popList getCount] - 1]];
 	geneIndex1 = [uniformUnsRand getUnsignedWithMin: 0L 
 				withMax:[parent getLength] - 1];
 	geneIndex2 = [uniformUnsRand getUnsignedWithMin: geneIndex1 
@@ -343,7 +343,7 @@ int compFunc( id a, id b ) {
 	unsigned geneIndex1, geneIndex2;
 	parent = 
 	    [popList atOffset: [uniformUnsRand getUnsignedWithMin: 0L 
-				       withMax:[popList count] - 1]];
+				       withMax:[popList getCount] - 1]];
 	geneIndex1 = [uniformUnsRand getUnsignedWithMin: 0L 
 				withMax:[parent getLength] - 1];
 	geneIndex2 = [uniformUnsRand getUnsignedWithMin: geneIndex1 
@@ -363,11 +363,11 @@ int compFunc( id a, id b ) {
 }
 
 -getBest{			// Returns the best genome
-//    printf( "Total %d\n", [population count]);
+//    printf( "Total %d\n", [population getCount]);
 //    id index = [population begin: [self getZone]], member = [index next];// First member
 //    printf( "Miembro %s con clave %s\n", [member getGenotype], (char* )[index getKey] );
 //    [index dropFrom: [self getZone]];
-    return [popList first];
+    return [popList getFirst];
 }
 
 
@@ -389,7 +389,7 @@ int compFunc( id a, id b ) {
 -printPopID {			// prints population
   unsigned i;
   printf( "Last Generation -- \n" );
-  for ( i = 0; i < [popList count]; i ++ ) {
+  for ( i = 0; i < [popList getCount]; i ++ ) {
     printf( "%s\n", [ [popList atOffset:i] getID ] );
   }
   return self;
